( cd usr/lib ; rm -rf libgoffice-1.so.0 )
( cd usr/lib ; ln -sf libgoffice-1.so.0.0.4 libgoffice-1.so.0 )
( cd usr/lib ; rm -rf libgoffice-1.so )
( cd usr/lib ; ln -sf libgoffice-1.so.0.0.4 libgoffice-1.so )
